@@ -65,9 +65,14 @@ sfg_point <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL ) {
 #' @export
 sfg_multipoint <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL ) {
   geometry_columns <- c(x,y,z,m)
-  rcpp_sfg_multipoint( obj, index_correct( geometry_columns ), xyzm(x,y,z,m) )
+  rcpp_sfg_multipoint(
+    obj
+    , index_correct( geometry_columns )
+    , xyzm(x,y,z,m)
+    )
 }
 
+
 #' sfg linestring
 #'
 #' constructs sfg LINESTRING object
@@ -77,6 +82,10 @@ sfg_multipoint <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL ) {
 #'
 #' @examples
 #'
+#' sfg_linestring( 1:2 )
+#' sfg_linestring( 1:3 )
+#' sfg_linestring( 1:4 )
+#'
 #' sfg_linestring( matrix( 1:24, ncol = 2 ) )
 #' sfg_linestring( matrix( 1:24, ncol = 3 ) )
 #' sfg_linestring( matrix( 1:24, ncol = 4 ) )
@@ -91,7 +100,11 @@ sfg_multipoint <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL ) {
 #' @export
 sfg_linestring <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL ) {
   geometry_columns <- c(x,y,z,m)
-  rcpp_sfg_linestring( obj, index_correct( geometry_columns ), xyzm(x,y,z,m) )
+  rcpp_sfg_linestring(
+    obj
+    , index_correct( geometry_columns )
+    , xyzm(x,y,z,m)
+    )
 }
 
 #' sfg multilinestring
@@ -126,7 +139,12 @@ sfg_linestring <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL ) {
 #' @export
 sfg_multilinestring <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL, linestring_id = NULL ) {
   geometry_columns <- c(x,y,z,m)
-  rcpp_sfg_multilinestring( obj, index_correct( geometry_columns ),  index_correct( linestring_id ), xyzm(x,y,z,m) )
+  rcpp_sfg_multilinestring(
+    obj
+    , index_correct( geometry_columns )
+    , index_correct( linestring_id )
+    , xyzm(x,y,z,m)
+    )
 }
 
 
@@ -163,7 +181,13 @@ sfg_multilinestring <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL, li
 #' @export
 sfg_polygon <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL, linestring_id = NULL, close = TRUE ) {
   geometry_columns <- c(x,y,z,m)
-  rcpp_sfg_polygon( obj, index_correct( geometry_columns ),  index_correct( linestring_id ), close, xyzm(x,y,z,m) )
+  rcpp_sfg_polygon(
+    obj
+    , index_correct( geometry_columns )
+    , index_correct( linestring_id )
+    , xyzm(x,y,z,m)
+    , close
+    )
 }
 
 
@@ -217,7 +241,14 @@ sfg_polygon <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL, linestring
 #' @export
 sfg_multipolygon <- function( obj, x = NULL, y = NULL, z = NULL, m = NULL, polygon_id = NULL, linestring_id = NULL, close = TRUE ) {
   geometry_columns <- c(x,y,z,m)
-  rcpp_sfg_multipolygon( obj, index_correct( geometry_columns ), index_correct( polygon_id ), index_correct( linestring_id ), close, xyzm(x,y,z,m) )
+  rcpp_sfg_multipolygon(
+    obj
+    , index_correct( geometry_columns )
+    , index_correct( polygon_id )
+    , index_correct( linestring_id )
+    , xyzm(x,y,z,m)
+    , close
+    )
 }
 
 
