@@ -2,8 +2,8 @@
 #define R_SFHEADERS_H
 
 #include <Rcpp.h>
-#include "sfheaders/shapes/shapes.hpp"
-#include "sfheaders/utils/utils.hpp"
+
+#include "geometries/utils/utils.hpp"
 
 #include "sfheaders/sfg/sfg.hpp"
 #include "sfheaders/sfc/sfc.hpp"
