@@ -1,5 +1,7 @@
 #include <Rcpp.h>
 
+
+#include "geometries/bbox/bbox.hpp"
 #include "sfheaders/sfc/bbox.hpp"
 #include "sfheaders/sfc/z_range.hpp"
 #include "sfheaders/sfc/m_range.hpp"
@@ -12,7 +14,7 @@
 // [[Rcpp::export]]
 SEXP rcpp_calculate_bbox( SEXP x, SEXP geometry_cols ) {
   Rcpp::NumericVector bbox = sfheaders::bbox::start_bbox();
-  sfheaders::bbox::calculate_bbox( bbox, x, geometry_cols );
+  geometries::bbox::calculate_bbox( bbox, x, geometry_cols );
   sfheaders::bbox::attach_bbox_attributes( bbox );
   return bbox;
 }
